powered by
Find column indices for vertical pagination
vert_pag_indices( obj, cpp = 40, colwidths = NULL, verbose = FALSE, rep_cols = 0L, fontspec, nosplitin = character() )
A list partitioning the vector of column indices into subsets for 1 or more horizontally paginated pages.
list
(ANY) object to be paginated. Must have a matrix_form() method.
ANY
matrix_form()
(numeric(1)) number of characters per page (width).
numeric(1)
(numeric) vector of column widths (in characters) for use in vertical pagination.
numeric
(flag) whether additional informative messages about the search for pagination breaks should be shown. Defaults to FALSE.
flag
FALSE
(numeric(1)) number of columns (not including row labels) to be repeated on every page. Defaults to 0.
(font_spec) a font_spec object specifying the font information to use for calculating string widths and heights, as returned by font_spec().
font_spec
font_spec()
(character) list of names of subtables where page breaks are not allowed, regardless of other considerations. Defaults to none.
character
mf <- basic_matrix_form(df = mtcars) colpaginds <- vert_pag_indices(mf, fontspec = font_spec()) lapply(colpaginds, function(j) mtcars[, j, drop = FALSE])
Run the code above in your browser using DataLab